==> release.12.2.28.1.tgz: cgi-cpn/dam/prontus_dam_ppart_save.pl <==
#!/usr/bin/perl

# ---------------------------------------------------------------
# Prontus CMS
# http://www.prontus.cl
# by Altavoz.net
#
# licensed under LGPL license.
# http://www.prontus.cl/license.html
# ---------------------------------------------------------------

# -------------------------------COMENTARIO GLOBAL---------------
# ---------------------------------------------------------------
# PROPOSITO.
# -----------
# Guarda datos en tabla ASSET
# -------------------------------BEGIN LIBRERIA------------------
# ---------------------------------------------------------------
# DECLARACIONES GLOBALES.
# ------------------------
use strict;
use utf8;

BEGIN {
    use FindBin qw($Bin);
    my $pathLibsProntus = $Bin;
    unshift(@INC,$pathLibsProntus);

    $pathLibsProntus =~ s/\/[^\/]+\/?$//;
    unshift(@INC,$pathLibsProntus);
}

##libs##
use lib_stdlog;
lib_stdlog::set_stdlog($0, 51200);
use prontus_varglb;
prontus_varglb::init();

use Artic;
use DBI;
use File::Copy;
use JSON;
use POSIX;
use glib_dbi_03;
use glib_fildir_03;
use glib_hrfec_03;
use glib_str_03;
use lib_bd;
use lib_dam;
use lib_prontus;
use lib_utils;
##/libs##

main:{
    lib_utils::setUtf8();

    if (scalar @ARGV < 1) {
        print "Parametros insuficientes Terminando\n";
        exit;
    }

    my $ts_artic;
    my $origen = $ARGV[0];
    if ($origen =~ m|.*/([\w\_\-]+)/site/artic/\d{8}/\w+/(\d{14})\.\w+$|) {
        $prontus_varglb::PRONTUS_ID = $1;
        $ts_artic   = $2;
    } else {
        print "Error al descomponer el path de entrada [$ARGV[0]]\n";
        exit;
    }

    if (&myselfRunning() > 1) {
        exit;
    }

    # valida el identificador de prontus
    if ($prontus_varglb::PRONTUS_ID eq '' || !lib_utils::valida_prontus($prontus_varglb::PRONTUS_ID)) {
        print STDERR "El identificador de Prontus es inválido\n";
        exit;
    }

    # Carga variables de configuracion.
    my $msg_load = lib_utils::load_config_by_id($prontus_varglb::PRONTUS_ID);
    if ($msg_load ne '') {
        print STDERR "Ha ocurrido un error: $msg_load\n";
        exit;
    }

    # Inicia conexion a BD
    my ($base, $msg_err_bd) = lib_bd::conectar_prontus_bd();
    if (! ref($base)) {
        print STDERR "Error al conectar a la BD: [$msg_err_bd]\n";
        exit;
    }

    lib_dam::procesa_artic($ts_artic,
                            $prontus_varglb::PRONTUS_ID,
                            $prontus_varglb::DIR_SERVER,
                            $prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'PUBLIC_SERVER_NAME'},
                            $prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'CPAN_SERVER_NAME'},
                            $base);
}

sub myselfRunning {
# Retorna las copias de del script que se encuentran corriendo.
    my $res = qx/ps axww | grep $0 | grep $ARGV[0] | grep -v ' grep ' | grep -v 'nice' | grep -v 'editor' | grep -v 'sh -c' | grep -v 'tail' | grep -v execIfMaster | wc -l/;
    $res =~ s/\D//gs;
    return $res;
} # myselfRunning

==> release.12.3.1.2.tgz: cgi-cpn/dam/prontus_dam_ppart_save.pl <==
#!/usr/bin/perl

# ---------------------------------------------------------------
# Prontus CMS
# http://www.prontus.cl
# by Altavoz.net
#
# licensed under LGPL license.
# http://www.prontus.cl/license.html
# ---------------------------------------------------------------

# -------------------------------COMENTARIO GLOBAL---------------
# ---------------------------------------------------------------
# PROPOSITO.
# -----------
# Guarda datos en tabla asset
# -------------------------------BEGIN LIBRERIA------------------
# ---------------------------------------------------------------
# DECLARACIONES GLOBALES.
# ------------------------
use strict;
use utf8;

BEGIN {
    use FindBin qw($Bin);
    my $pathLibsProntus = $Bin;
    unshift(@INC,$pathLibsProntus);

    $pathLibsProntus =~ s/\/[^\/]+\/?$//;
    unshift(@INC,$pathLibsProntus);
}

##libs##
use lib_stdlog;
lib_stdlog::set_stdlog($0, 51200);
use prontus_varglb;
prontus_varglb::init();

use Artic;
use DBI;
use File::Copy;
use JSON;
use POSIX;
use glib_dbi_03;
use glib_fildir_03;
use glib_hrfec_03;
use glib_str_03;
use lib_bd;
use lib_dam;
use lib_lang;
use lib_maxrunning;
use lib_prontus;
use lib_utils;
##/libs##

main:{
    lib_utils::setUp();
    if (scalar @ARGV < 1) {
        print lib_lang::get_message('global_use_instructions');
        print "perl $0 <origin>\n";
        exit;
    }

    my $ts_artic;
    my $origen = $ARGV[0];
    my $prontus_id;
    if ($origen =~ m|.*/([\w\_\-]+)/site/artic/\d{8}/\w+/(\d{14})\.\w+$|) {
        $prontus_id = $1;
        $ts_artic = $2;
    } else {
        print STDERR lib_lang::get_interpolated_message('global_invalid_path', $ARGV[0]) , "\n";
        exit;
    }

    # Carga variables de configuracion.
    my $msg_load = lib_utils::load_config_by_id($prontus_id);
    if ($msg_load ne '') {
        print "$msg_load\n";
        exit;
    }

    if (lib_maxrunning::myselfRunningArgs() > 1) {
        print lib_lang::get_message('global_already_running'). "\n";
        exit;
    }

    # Inicia conexion a BD
    my ($base, $msg_err_bd) = lib_bd::conectar_prontus_bd();
    if (! ref($base)) {
        print STDERR $msg_err_bd , "\n";
        exit;
    }

    lib_dam::procesa_artic($ts_artic,
                            $prontus_varglb::PRONTUS_ID,
                            $prontus_varglb::DIR_SERVER,
                            $prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'PUBLIC_SERVER_NAME'},
                            $prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'CPAN_SERVER_NAME'},
                            $base);
}
